[−][src]Struct mailchimp::types::ABTestingOptionsType
The days of the week to send a daily RSS Campaign.
Fields
split_test: Option<String>The type of AB split to run.
pick_winner: Option<String>How we should evaluate a winner. Based on ‘opens’, ‘clicks’, or ‘manual’.
wait_units: Option<String>How unit of time for measuring the winner (‘hours’ or ‘days’). This cannot be changed after a campaign is sent.
wait_time: Option<u64>The amount of time to wait before picking a winner. This cannot be changed after a campaign is sent.
split_size: Option<u64>The size of the split groups. Campaigns split based on ‘schedule’ are forced to have a 50⁄50 split. Valid split integers are between 1-50.
from_name_a: Option<String>For campaigns split on ‘From Name’, the name for Group A.
from_name_b: Option<String>For campaigns split on ‘From Name’, the name for Group B.
reply_email_a: Option<String>For campaigns split on ‘From Name’, the reply-to address for Group A.
reply_email_b: Option<String>For campaigns split on ‘From Name’, the reply-to address for Group B.
subject_a: Option<String>For campaigns split on ‘Subject Line’, the subject line for Group A.
subject_b: Option<String>For campaigns split on ‘Subject Line’, the subject line for Group B.
send_time_a: Option<String>The send time for Group A.
send_time_b: Option<String>The send time for Group B.
send_time_winner: Option<String>The send time for the winning version.