pub struct CampaignDefaultsType {
pub from_name: Option<String>,
pub from_email: Option<String>,
pub subject: Option<String>,
pub language: Option<String>,
}Expand description
Campaign Defaults Type
Fields
from_name: Option<String>The default from name for campaigns sent to this list.
from_email: Option<String>The default from email for campaigns sent to this list.
subject: Option<String>The default subject line for campaigns sent to this list.
language: Option<String>The default language for this lists’s forms.