pub struct OpensType {
pub opens_total: u64,
pub unique_opens: u64,
pub open_rate: f32,
pub last_open: String,
}Expand description
An object describing the open activity for the campaign.
Fields
opens_total: u64The total number of opens for a campaign.
unique_opens: u64The total number of unique opens.
open_rate: f32The number of unique opens divided by the total number of successful deliveries.
last_open: StringThe date and time of the last recorded open in ISO 8601 format.