pub struct SendChecklistType {
pub is_ready: bool,
pub items: Vec<ChecklistItem>,
pub _links: Vec<LinkType>,
}Expand description
Review the send checklist for your campaign, and resolve any issues before sending.
Fields
is_ready: boolThe id of the template to use.
items: Vec<ChecklistItem>Content for the sections of the template. Each key should be the unique mc:edit area name from the template.
_links: Vec<LinkType>A list of link types and descriptions for the API schema documents.