pub type CampaignSettingsType = AutomationCampaignSettingsType;Expand description
Campaigns Settings Type
Aliased Type
pub struct CampaignSettingsType {Show 17 fields
pub subject_line: Option<String>,
pub preview_text: Option<String>,
pub title: Option<String>,
pub from_name: Option<String>,
pub reply_to: Option<String>,
pub authenticate: Option<bool>,
pub use_conversation: Option<bool>,
pub to_name: Option<String>,
pub folder_id: Option<String>,
pub auto_footer: Option<bool>,
pub inline_css: Option<bool>,
pub auto_tweet: Option<bool>,
pub auto_fb_post: Option<Vec<u64>>,
pub fb_comments: Option<bool>,
pub timewarp: Option<bool>,
pub template_id: Option<u64>,
pub drag_and_drop: Option<bool>,
}Fields
subject_line: Option<String>The subject line for the campaign.
preview_text: Option<String>The preview text for the campaign.
title: Option<String>The title of the Automation.
from_name: Option<String>Desc: The ‘from’ name for the Automation (not an email address).
reply_to: Option<String>Desc: The reply-to email address for the Automation.
authenticate: Option<bool>Desc: Whether Mailchimp authenticated the Automation. Defaults to true.
use_conversation: Option<bool>Desc: Whether to use Mailchimp’s Conversations feature to manage out-of-office replies.
to_name: Option<String>Desc: The Automation’s custom ‘To’ name, typically the first name merge field.
folder_id: Option<String>Desc: If the campaign is listed in a folder, the id for that folder.
Desc: Whether to automatically append Mailchimp’s default footer to the Automation.
inline_css: Option<bool>Desc: Whether to automatically inline the CSS included with the Automation content.
auto_tweet: Option<bool>Automatically tweet a link to the campaign archive page when the campaign is sent.
auto_fb_post: Option<Vec<u64>>An array of Facebook page ids to auto-post to.
fb_comments: Option<bool>Allows Facebook comments on the campaign (also force-enables the Campaign Archive toolbar). Defaults to true.
timewarp: Option<bool>Send this campaign using Timewarp.
template_id: Option<u64>Allows Facebook comments on the campaign (also force-enables the Campaign Archive toolbar). Defaults to true.
drag_and_drop: Option<bool>Whether the campaign uses the drag-and-drop editor.